@@ -2,6 +2,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
+import logging
 import xmlrpclib
 
 from djblets.siteconfig.models import SiteConfiguration
@@ -176,11 +177,10 @@ class Bugzilla(object):
         else:
             params['ids'] = [bug_id]
             params['data'] = url
-            params['content_type'] = 'text/plain'
+            params['content_type'] = 'text/x-review-board-request'
 
         params['file_name'] = 'reviewboard-%d-url.txt' % review_id
         params['summary'] = summary
-        params['comment'] = comment
         if flags:
             params['flags'] = flags
 
@@ -189,6 +189,13 @@ class Bugzilla(object):
         else:
             self.proxy.Bug.add_attachment(params)
 
+        # FIXME: The comment should be posted as part of add/update_attachment,
+        # but due to bug 508541, the comment won't be included in the bugmail,
+        # so until that bug is fixed, we sent the comment separately, after
+        # setting the flag.
+        self.post_comment(bug_id, comment)
+
+
     @xmlrpc_to_bugzilla_errors
     def get_rb_attachments(self, bug_id):
         """Get all attachments that contain review-request URLs."""
@@ -205,9 +212,11 @@ class Bugzilla(object):
                 a['content_type'] == 'text/x-review-board-request']
 
     @xmlrpc_to_bugzilla_errors
-    def r_plus_attachment(self, bug_id, reviewer, rb_url):
+    def r_plus_attachment(self, bug_id, reviewer, comment, rb_url):
         """Set a review flag to "+"."""
 
+        logging.info('r+ from %s on bug %d.' % (reviewer, bug_id))
+
         rb_attachment = None
         attachments = self.get_rb_attachments(bug_id)
 
@@ -236,6 +245,12 @@ class Bugzilla(object):
         }
 
         self.proxy.Bug.update_attachment(params)
+        # FIXME: The comment should be posted as part of update_attachment,
+        # but due to bug 508541, the comment won't be included in the bugmail,
+        # so until that bug is fixed, we sent the comment separately, after
+        # setting the flag.
+        self.post_comment(bug_id, comment)
+
 
     @property
     def transport(self):
