@@ -2,8 +2,6 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-import logging
-
 from django.contrib.auth.models import User
 from django.db import models
 
@@ -28,7 +26,7 @@ def get_or_create_bugzilla_users(user_data):
             bugzilla_user_map = BugzillaUserMap.objects.get(
                 bugzilla_user_id=bz_user_id)
         except BugzillaUserMap.DoesNotExist:
-            user = User(username=email, password='!', first_name=real_name,
+            user = User(username=bz_user_id, password='!', first_name=real_name,
                         email=email, is_active=can_login)
             user.save()
             bugzilla_user_map = BugzillaUserMap(user=user,
@@ -38,8 +36,11 @@ def get_or_create_bugzilla_users(user_data):
             modified = False
             user = bugzilla_user_map.user
 
-            if user.username != email:
-                user.username = email
+            if user.username != bz_user_id:
+                user.username = bz_user_id
+                modified = True
+
+            if user.email != email:
                 user.email = email
                 modified = True
 
@@ -51,8 +52,14 @@ def get_or_create_bugzilla_users(user_data):
                 user.is_active = can_login
                 modified = True
 
+            profile = user.get_profile()
+
+            if not profile.is_private:
+                profile.is_private = True
+                profile.save()
+
             if modified:
                 user.save()
 
         users.append(user)
-    return users
\ No newline at end of file
+    return users
